Parser

Struct Parser 

pub struct Parser { /* private fields */ }
Chumsky-based parser that converts tokens into an AST.

Implementations

Source

impl ChumskyParser

pub fn new(tokens: Vec<Token>, interner: ThreadedRodeo) -> Self

Create a new parser from tokens and an interner produced by the lexer.

pub fn parse(self) -> MultiErrorResult<(Ast, ThreadedRodeo)>

Parse the tokens into an AST, returning the AST and the interner.

Returns all parse errors if parsing fails, not just the first one.