pub struct Parser { /* private fields */ }Expand description
Chumsky-based parser that converts tokens into an AST.
Implementations
Sourceimpl ChumskyParser
impl ChumskyParser
Sourcepub fn new(tokens: Vec<Token>, interner: ThreadedRodeo) -> Self
pub fn new(tokens: Vec<Token>, interner: ThreadedRodeo) -> Self
Create a new parser from tokens and an interner produced by the lexer.
Sourcepub fn parse(self) -> MultiErrorResult<(Ast, ThreadedRodeo)>
pub fn parse(self) -> MultiErrorResult<(Ast, ThreadedRodeo)>
Parse the tokens into an AST, returning the AST and the interner.
Returns all parse errors if parsing fails, not just the first one.